<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * BuddyPress plugin compatibility Class
 * 
 * 
 * @package WPWeb WooCommerce Collections
 * @since 1.1.5
 */
class Woo_Cl_BuddyPress {

	/**
	 * Settings for BuddyPress
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_register_um_settings( $settings ){
		
		$bp_settings = array(
					array(
		                'desc' 			=> sprintf( esc_html__( 'Check this box to display My %s on BuddyPress Profile page.', 'woocl' ), woo_cl_get_label_plural() ),
						'id' 			=> 'cl_enable_buddypress_myaccount_page',
		                'std' 			=> '',
		                'default' 		=> '',
		                'type' 			=> 'checkbox',
				        'checkboxgroup' => ''
			        ),
	            );

	    $settings = array_merge( $settings, $bp_settings );

		return $settings;
	}

	/**
	 * Register style for Buddypress account page
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_buddypress_public_style(){
		global $woo_cl_scripts;

		if( get_option( 'cl_enable_buddypress_myaccount_page' ) == 'yes' && bp_is_current_action('mycollection') ){

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-collection-listing', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-collection-listing' ); // Enqueue Collection Listing style

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-item-listing', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-item-listing' ); // Enqueue Item listing style

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-collection-edit', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-collection-edit' ); // Enqueue collection edit style

			$woo_cl_scripts->woo_cl_wp_register_style( 'woo-cl-email-share', '', array(), WOO_CL_LIB_VER );
			wp_enqueue_style( 'woo-cl-email-share' ); // Enqueue email share style
		}
	}


	/**
	 * Register script for Buddypress account page
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_buddypress_public_scripts(){
		

		if( get_option( 'cl_enable_buddypress_myaccount_page' ) == 'yes' && bp_is_current_action('mycollection') ) {
			//Get all Messages
			$messages	= woo_cl_messages();

			wp_register_script( 'woo-cl-ajax-listing', WOO_CL_URL. 'includes/js/woo-cl-ajax-listing.js', array('jquery' ), WOO_CL_LIB_VER, true );
			wp_enqueue_script( 'woo-cl-ajax-listing' ); //enqueue ajax listing script
			wp_register_script( 'woo-cl-public-script', WOO_CL_URL. 'includes/js/woo-cl-public.js', array('jquery' ), WOO_CL_LIB_VER, true );
			
			//localize script to pass some variable to javascript file from php file
			//pass ajax url to access wordpress ajax file at front side for public
			wp_localize_script( 'woo-cl-public-script','Woo_cl_Public_Ajax',array(
																				'ajaxurl' 			=> admin_url( 'admin-ajax.php', ( is_ssl() ? 'https' : 'http' ) ),
																				'no_more_coll' 		=> isset( $messages['no_more_coll'] ) 		? $messages['no_more_coll'] 		: '',
																				'no_more_coll_item'	=> isset( $messages['no_more_coll_item'] ) 	? $messages['no_more_coll_item']	: '',
																				'select_all_chk'	=> esc_html__("Select All", "woocl"),
																				'unselect_all_chk'	=> esc_html__("Unselect All", "woocl"),
																				'add_bulk_products_to_cart_error'	=> esc_html__("Something worng, No item added to cart.", "woocl"),
																			));
			wp_enqueue_script( 'woo-cl-public-script' ); //enqueue public script for item & edit item listing
		}
	}


	/**
	 * Added Tab My Collections on BuddyPress Profile
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_buddypress_profile_tab_mycollections() {

		global $bp;

		//Build counts for collections tab
		$count = woo_cl_count_user_collections( bp_current_user_id(), WOO_CL_POST_TYPE_COLL );
		$count_msg = !empty( $count ) ? '<span class="count">'. $count .'</span>' : '<span class="no-count">0</span>';

		//Create tab
	    bp_core_new_nav_item( array( 
            'name' => sprintf( esc_html__( 'My %s %s', 'woocl' ), woo_cl_get_label_plural(), $count_msg ),
            'slug' => 'mycollection', 
            'screen_function' 	=> array( $this, 'woo_cl_buddypress_mycollection_callback' ), 
            'position' 			=> 40,
            'show_for_displayed_user' => false,
            'parent_url'      	=> $bp->displayed_user->domain,
			'parent_slug'     	=> $bp->profile->slug,
			'default_subnav_slug' => 'mycollection'
      	) );
	}
	

	/**
	 * My Collections Tab Callback on BuddyPress Profile
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_buddypress_mycollection_callback() {

		//Action to display title and content
		add_action( 'bp_template_title', array( $this, 'woo_cl_buddypress_mycollections_title' ) );
    	add_action( 'bp_template_content', array( $this, 'woo_cl_buddypress_mycollections_content' ) );

    	//Load buddypress template
    	bp_core_load_template( apply_filters( 'woo_cl_bp_core_template_plugin', 'members/single/plugins' ) );
	}

	/**
	 * My Collections Title on BuddyPress Profile
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_buddypress_mycollections_title() {
	  	echo sprintf( esc_html__( 'My %s', 'woocl' ), woo_cl_get_label_plural() );
	}

	/**
	 * My Collections Tab Content on BuddyPress Profile
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_buddypress_mycollections_content() {

		//Get no of collections to display
	  	$no_of_collections	=  woo_cl_get_no_of_collection_on_my_account_page();		

		$args = array(
						'post_status'	 	=> array( 'publish', 'private' ),							
						'posts_per_page' 	=> $no_of_collections,							
						'paged'	 		 	=> 1,							
						'collection_title'	=> sprintf( esc_html__( 'My %s', 'woocl' ), woo_cl_get_label_plural() ),							
						'enable_see_all'	=> 'true',							
						'show_count'		=> 'true',
						'fixed_coll'	 	=> true
					);

		woo_cl_my_collections( apply_filters( 'woo_cl_buddypress_account_page_collection_args', $args ) );
	}

	/**
	 * Adding Hooks
	 * 
	 * Adding proper hooks for the Buddypress compability.
	 * 
	 * @package WPWeb WooCommerce Collections
 	* @since 1.1.5
	 */
	public function add_hooks() {

		add_filter('woo_cl_before_seaching_display_settings', array( $this, 'woo_cl_register_um_settings'));

		//style for public
		add_action( 'wp_enqueue_scripts', array( $this, 'woo_cl_buddypress_public_style' ) );

		//script for popup
		add_action( 'wp_enqueue_scripts', array( $this, 'woo_cl_buddypress_public_scripts' ) );

		//Check if my collections on BuddyPress profile page enabled
		if( get_option( 'cl_enable_buddypress_myaccount_page' ) == 'yes' ) {

			//Action to add My Collections on BuddyPress page
	 		add_action( 'bp_setup_nav', array( $this, 'woo_cl_buddypress_profile_tab_mycollections' ) );
	 	}

	}
}