<?php
// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * WC Vendors plugin compatibility Class
 * 
 * 
 * @package WPWeb WooCommerce Collections
 * @since 1.1.5
 */
class Woo_Cl_WC_Vendors {

	/**
	 * Settings for WC Vendors
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_register_wcvendors_settings( $settings ){
		
		$wcv_settings = array(
					array(
		                'desc' 			=> sprintf( esc_html__( 'Check this box to display My %s on WC Vendors Dashboard page.', 'woocl' ), woo_cl_get_label_plural() ),
						'id' 			=> 'cl_enable_wcvendor_dashboard_page',
		                'std' 			=> '',
		                'default' 		=> '',
		                'type' 			=> 'checkbox',
				        'checkboxgroup' => ''
			        ),
	            );

	   	$settings = array_merge( $settings, $wcv_settings );

	   	return $settings;
	}

	/**
	 * My Collections on WC Vendors Dashboard
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_wcvendors_dashboard_tab_mycollections( $items) {

		//Get collection page and added tab
		global $current_user, $woo_cl_model;
		$username = !empty( $current_user->data->user_login ) ? $current_user->data->user_login : 'guest';
		$collection_author_url = $woo_cl_model->woo_cl_get_collection_page_url( $username );

		$items['my_collection_page'] = array(
			'url' 		=> $collection_author_url,
			'label' 	=> sprintf( esc_html__( 'My %s', 'wpewoowl' ), woo_cl_get_label_plural() ),
			'target'	=> '_top'
		);

		return $items;
	}


	/**
	 * My Collections on WC Vendors Dashboard Pro
	 * 
	 * @package WPWeb WooCommerce Collections
	 * @since 1.1.5
	 */
	public function woo_cl_wcvendors_dashboard_pro_tab_mycollections( $dashboard_pages ) {

		//Get collection page and added tab
		global $current_user, $woo_cl_model;
		$username = !empty( $current_user->data->user_login ) ? $current_user->data->user_login : 'guest';
		$collection_author_url = $woo_cl_model->woo_cl_get_collection_page_url( $username );
		$dashboard_pages[ 'mycollection' ] = array( 
			'slug'			=> $collection_author_url, 
			'label'			=> sprintf( esc_html__( 'My %s', 'woocl' ), woo_cl_get_label_plural() ), 
			'actions'		=> array()
		);

		return $dashboard_pages;
	}

	/**
	 * Adding Hooks
	 * 
	 * Adding proper hooks for the WC Vendors compability.
	 * 
	 * @package WPWeb WooCommerce Collections
 	* @since 1.1.5
	 */
	public function add_hooks() {

		add_filter('woo_cl_before_seaching_display_settings', array( $this, 'woo_cl_register_wcvendors_settings'));

		//Check if my collections on WC Vendors dashboard page enabled
		if( get_option( 'cl_enable_wcvendor_dashboard_page' ) == 'yes' ) {

			//Action to add My Collections on WC Vendors page
	 		add_action( 'wcv_dashboard_nav_items', array( $this, 'woo_cl_wcvendors_dashboard_tab_mycollections' ),10,1 );
	 		add_filter( 'wcv_pro_dashboard_urls', array( $this, 'woo_cl_wcvendors_dashboard_pro_tab_mycollections' ) );
	 	}

	}
}